@@ -24,7 +24,13 @@ class Class_1(object):
 class Class_2(object):
     @classmethod
     def method(cls, *args, **kwargs):
-        return args, kwargs
+        return cls, args, kwargs
+
+class Class_2_1(Class_2):
+    pass
+
+class Class_2_2(Class_2_1):
+    pass
 
 class Class_3(object):
     @staticmethod
@@ -36,7 +42,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_function_wrapper(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -60,7 +66,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_function_wrapper_instance_method(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -88,7 +94,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_function_wrapper_class_method(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -115,7 +121,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_wrap_function_module_name(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -136,7 +142,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_wrap_function_module(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -159,7 +165,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_wrap_instance_method_module_name(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -183,7 +189,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_wrap_class_method_module_name(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -199,13 +205,38 @@ class TestMonkeyPatching(unittest.TestCase):
 
         result = Class_2.method(*_args, **_kwargs)
 
-        self.assertEqual(result, (_args, _kwargs))
+        self.assertEqual(result, (Class_2, _args, _kwargs))
+        self.assertEqual(called[0], (_args, _kwargs))
+
+    def test_wrap_class_method_inherited(self):
+        _args = (1, 2)
+        _kwargs = {'one': 1, 'two': 2}
+
+        called = []
+
+        def wrapper(wrapped, instance, args, kwargs):
+            called.append((args, kwargs))
+            self.assertEqual(args, _args)
+            self.assertEqual(kwargs, _kwargs)
+            return wrapped(*args, **kwargs)
+
+        wrapt.wrap_function_wrapper(__name__, 'Class_2_1.method',
+                wrapper)
+
+        result = Class_2_1.method(*_args, **_kwargs)
+        self.assertEqual(result, (Class_2_1, _args, _kwargs))
+        self.assertEqual(called[0], (_args, _kwargs))
+
+        called.pop()
+
+        result = Class_2_2.method(*_args, **_kwargs)
+        self.assertEqual(result, (Class_2_2, _args, _kwargs))
         self.assertEqual(called[0], (_args, _kwargs))
 
     def test_wrap_static_method_module_name(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -227,7 +258,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_patch_function_module_name(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -247,7 +278,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_patch_function_module(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -272,7 +303,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_transient_function_wrapper(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -298,7 +329,7 @@ class TestMonkeyPatching(unittest.TestCase):
     def test_transient_function_wrapper_instance_method(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -329,7 +360,7 @@ class TestExplicitMonkeyPatching(unittest.TestCase):
     def test_patch_instance_method_class(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -357,7 +388,7 @@ class TestExplicitMonkeyPatching(unittest.TestCase):
     def test_patch_instance_method_dict(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -385,7 +416,7 @@ class TestExplicitMonkeyPatching(unittest.TestCase):
     def test_patch_instance_method_instance(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
@@ -413,7 +444,7 @@ class TestExplicitMonkeyPatching(unittest.TestCase):
     def test_patch_instance_method_extracted(self):
 
         _args = (1, 2)
-        _kwargs = { 'one': 1, 'two': 2 }
+        _kwargs = {'one': 1, 'two': 2}
 
         called = []
 
